==> jc-1.4.0.tar.gz: javax/swing/JPopupMenu__24MediumWeightPopup.h <==
// class javax.swing.JPopupMenu$MediumWeightPopup

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class a52c288050fd199 java_awt_Panel
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5b3ccd2953186a3a javax_swing_JPopupMenu__24MediumWeightPopup

// header file dependencies
// @dep_header java_awt_Panel

#include "java/awt/Panel.h"

#ifndef _JC_javax_swing_JPopupMenu__24MediumWeightPopup_H_
#define _JC_javax_swing_JPopupMenu__24MediumWeightPopup_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_refs	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_nonrefs	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$refs	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$refs;
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$nonrefs	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$object;

typedef const struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vmethods	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtable	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method$_init$0ad2bcb8655c238d(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *, struct _jc_javax_swing_JPopupMenu$object *, struct _jc_java_awt_Container$object *);

// Virtual methods
extern void _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *);
extern void _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method$show$9d69c93242b99fe6(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method_info$show$9d69c93242b99fe6;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *);
	void	(*show$9d69c93242b99fe6)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Panel$vmethods	java_awt_Panel;
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vmethods	javax_swing_JPopupMenu__24MediumWeightPopup;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$refs {
    _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_refs	javax_swing_JPopupMenu__24MediumWeightPopup;
    _jc_java_awt_Panel$sub_refs	java_awt_Panel;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Panel$sub_nonrefs	java_awt_Panel;
    _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_nonrefs	javax_swing_JPopupMenu__24MediumWeightPopup;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object {
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype _jc_javax_swing_JPopupMenu__24MediumWeightPopup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24MediumWeightPopup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24MediumWeightPopup$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24MediumWeightPopup_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JPopupMenu__24MediumWeightPopup.h <==
// class javax.swing.JPopupMenu$MediumWeightPopup

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class a52c288050fd199 java_awt_Panel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5b3ccd2953186a3a javax_swing_JPopupMenu__24MediumWeightPopup

// header file dependencies
// @dep_header java_awt_Panel

#include "java/awt/Panel.h"

#ifndef _JC_javax_swing_JPopupMenu__24MediumWeightPopup_H_
#define _JC_javax_swing_JPopupMenu__24MediumWeightPopup_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_refs	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_nonrefs	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$refs	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$refs;
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$nonrefs	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$object;

typedef const struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vmethods	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtable	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method$_init$0ad2bcb8655c238d(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *, struct _jc_javax_swing_JPopupMenu$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method$show$9d69c93242b99fe6(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_JPopupMenu__24MediumWeightPopup$method_info$show$9d69c93242b99fe6;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *) _JC_JCNI_ATTR;
	void	(*show$9d69c93242b99fe6)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Panel$vmethods	java_awt_Panel;
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vmethods	javax_swing_JPopupMenu__24MediumWeightPopup;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$refs {
    _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_refs	javax_swing_JPopupMenu__24MediumWeightPopup;
    _jc_java_awt_Panel$sub_refs	java_awt_Panel;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Panel$sub_nonrefs	java_awt_Panel;
    _jc_javax_swing_JPopupMenu__24MediumWeightPopup$sub_nonrefs	javax_swing_JPopupMenu__24MediumWeightPopup;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24MediumWeightPopup$object {
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24MediumWeightPopup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24MediumWeightPopup$vtype _jc_javax_swing_JPopupMenu__24MediumWeightPopup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24MediumWeightPopup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24MediumWeightPopup$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24MediumWeightPopup_H_ */
